package com.jpattern.gwt.client;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.jpattern.gwt.client.event.AOnErrorAction;
import com.jpattern.gwt.client.event.IEvent;
import com.jpattern.gwt.client.event.IEventCallback;
import com.jpattern.gwt.client.presenter.IPresenter;
import com.jpattern.shared.result.IErrorMessage;

/**
 * 
 * @author Francesco Cina'
 *
 * 21/set/2011
 */
public class ManagedErrorService implements IManagedErrorService {

	private Map<String, List<AOnErrorAction>> errorActionMap = new HashMap<String, List<AOnErrorAction>>();
	
	@Override
	public void register(String errorCodeTrigger, AOnErrorAction onErrorAction) {
		if (!errorActionMap.containsKey(errorCodeTrigger)) {
			errorActionMap.put(errorCodeTrigger, new ArrayList<AOnErrorAction>());
		}
		errorActionMap.get(errorCodeTrigger).add(onErrorAction);
	}

	@Override
	public <T> void launch(IErrorMessage errorMessage, IPresenter presenter, IEvent<T> event, IEventCallback<T> eventCallback ) {
		String errorCode = errorMessage.getName();
		if (errorActionMap.containsKey(errorCode)) {
			for ( AOnErrorAction onErrorAction : errorActionMap.get(errorCode) ) {
				onErrorAction.launch(errorMessage, presenter, event, eventCallback);
			}
		}
	}

}
