package com.jpattern.gwt.client.view;

import com.google.gwt.user.client.ui.HasWidgets;
import com.google.gwt.user.client.ui.PopupPanel;
import com.jpattern.gwt.client.presenter.IPresenter;

/**
 * 
 * A View based on the gwt PopupPanel component
 * 
 * @author Francesco Cina'
 *
 * 20 Apr 2011
 */
public abstract class AGwtPopupPanelView<T extends IPresenter> extends PopupPanel implements IView {

	private T presenter;
	private IErrorArea errorArea;

	/**
	 * @param autoHide
	 *            <code>true</code> if the popup should be automatically hidden
	 *            when the user clicks outside of it or the history token
	 *            changes.
	 * @param modal
	 *            <code>true</code> if keyboard or mouse events that do not
	 *            target the PopupPanel or its children should be ignored
	 */
	public AGwtPopupPanelView(boolean autoHide, boolean modal) {
		super(autoHide, modal);
	}
	   
	@Override
	public final void render(HasWidgets container) {
		show();
	}
	

	@SuppressWarnings("unchecked")
	@Override
	public final void visit(IPresenter presenter) {
		this.presenter = (T) presenter;
	}

	@Override
	public final T getPresenter() {
		return presenter;
	}

	@Override
	public final IErrorArea getErrorArea() {
		if (errorArea == null) {
			errorArea = buildErrorArea();
		}
		return errorArea;
	}

	@Override
	public final void onUnload() { 
		onUnloadView();
		getPresenter().onUnloadPresenter();
	}
	
	protected abstract void onUnloadView();
	
	protected abstract IErrorArea buildErrorArea();
	
}
